@@ -1,3 +1,4 @@
+# Copyright (C) 2018 AT&T
 # Copyright (C) 2015 Ericsson AB
 # Copyright (c) 2015 Gigamon
 #
@@ -18,9 +19,10 @@ import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.orm import exc
 
-from neutron.db import common_db_mixin as base_db
 from neutron_lib import constants
 from neutron_lib.db import model_base
+from neutron_lib.db import model_query
+from neutron_lib.db import utils as db_utils
 from neutron_lib.plugins import directory
 from neutron_taas.extensions import taas
 from oslo_config import cfg
@@ -59,6 +61,7 @@ class TapFlow(model_base.BASEV2, model_base.HasId,
                           nullable=False)
     status = sa.Column(sa.String(16), nullable=False,
                        server_default=constants.ACTIVE)
+    vlan_filter = sa.Column(sa.String(1024), nullable=True)
 
 
 class TapIdAssociation(model_base.BASEV2):
@@ -78,20 +81,20 @@ class TapIdAssociation(model_base.BASEV2):
         primaryjoin='TapService.id==TapIdAssociation.tap_service_id')
 
 
-class Taas_db_Mixin(taas.TaasPluginBase, base_db.CommonDbMixin):
+class Taas_db_Mixin(taas.TaasPluginBase):
 
     def _core_plugin(self):
         return directory.get_plugin()
 
     def _get_tap_service(self, context, id):
         try:
-            return self._get_by_id(context, TapService, id)
+            return model_query.get_by_id(context, TapService, id)
         except exc.NoResultFound:
             raise taas.TapServiceNotFound(tap_id=id)
 
     def _get_tap_id_association(self, context, tap_service_id):
         try:
-            query = self._model_query(context, TapIdAssociation)
+            query = model_query.query_with_hooks(context, TapIdAssociation)
             return query.filter(TapIdAssociation.tap_service_id ==
                                 tap_service_id).one()
         except exc.NoResultFound:
@@ -99,7 +102,7 @@ class Taas_db_Mixin(taas.TaasPluginBase, base_db.CommonDbMixin):
 
     def _get_tap_flow(self, context, id):
         try:
-            return self._get_by_id(context, TapFlow, id)
+            return model_query.get_by_id(context, TapFlow, id)
         except Exception:
             raise taas.TapFlowNotFound(flow_id=id)
 
@@ -111,7 +114,7 @@ class Taas_db_Mixin(taas.TaasPluginBase, base_db.CommonDbMixin):
                'port_id': tap_service['port_id'],
                'status': tap_service['status']}
 
-        return self._fields(res, fields)
+        return db_utils.resource_fields(res, fields)
 
     def _make_tap_id_association_dict(self, tap_id_association):
         res = {'tap_service_id': tap_id_association['tap_service_id'],
@@ -127,9 +130,10 @@ class Taas_db_Mixin(taas.TaasPluginBase, base_db.CommonDbMixin):
                'description': tap_flow['description'],
                'source_port': tap_flow['source_port'],
                'direction': tap_flow['direction'],
-               'status': tap_flow['status']}
+               'status': tap_flow['status'],
+               'vlan_filter': tap_flow['vlan_filter']}
 
-        return self._fields(res, fields)
+        return db_utils.resource_fields(res, fields)
 
     def create_tap_service(self, context, tap_service):
         LOG.debug("create_tap_service() called")
@@ -208,6 +212,7 @@ class Taas_db_Mixin(taas.TaasPluginBase, base_db.CommonDbMixin):
                 source_port=t_f['source_port'],
                 direction=t_f['direction'],
                 status=constants.ACTIVE,
+                vlan_filter=t_f['vlan_filter'],
             )
             context.session.add(tap_flow_db)
 
@@ -251,17 +256,17 @@ class Taas_db_Mixin(taas.TaasPluginBase, base_db.CommonDbMixin):
                          sorts=None, limit=None, marker=None,
                          page_reverse=False):
         LOG.debug("get_tap_services() called")
-        return self._get_collection(context, TapService,
-                                    self._make_tap_service_dict,
-                                    filters=filters, fields=fields)
+        return model_query.get_collection(context, TapService,
+                                          self._make_tap_service_dict,
+                                          filters=filters, fields=fields)
 
     def get_tap_flows(self, context, filters=None, fields=None,
                       sorts=None, limit=None, marker=None,
                       page_reverse=False):
         LOG.debug("get_tap_flows() called")
-        return self._get_collection(context, TapFlow,
-                                    self._make_tap_flow_dict,
-                                    filters=filters, fields=fields)
+        return model_query.get_collection(context, TapFlow,
+                                          self._make_tap_flow_dict,
+                                          filters=filters, fields=fields)
 
     def _get_port_details(self, context, port_id):
         with context.session.begin(subtransactions=True):
